import java.io.*;
import java.util.ArrayList;
import javax.swing.*;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.Container;
import java.awt.BorderLayout;

/**
 * Takes as input a .lopsil and a .srm files and 
 * returns a .java and a .aj file
 * 
 * 
 *
 */
public class Lopsil2aj extends JPanel{
	public static final String javaCode[] =
		{"import lopsil.*;",
		"import lopsil.device.*;\n",
		"import gpslib4j.*;\n\n"};
	public static final String AJcode[] =
	{"	Object around(): notInAdvice() && srmCalls() {",
		"		Object result = new Object();",
		"		/* Build action from join point and create instance of SecurityPolicy */",
		"		Action a = new Action(thisJoinPoint);",
		"		Reaction r1 = p.react(a);",
		"		a.setReaction(r1);",
		"\n		if(r1.isOK()) {",
		"			if(a.getReturnType().equals(\"void\"))",
		"				return proceed();",
		"			else",
		"				result = proceed();",
		"			a.setResult(result);",
		"			Reaction r2 = p.react(a);",
		"			if(r2.isOK())",
		"			    return result;",
		"			else if(r2.isReplace()) {",
		"				try {",
		"					r1.checkReplVal(thisJoinPoint.getSignature().getDeclaringType());",
		"				} catch (LopsilException le) {",
		"					JOptionPane.showConfirmDialog(null, le.toString() +  \"\\nSystem will now exit.\", \"Error!\", ",
		"						JOptionPane.DEFAULT_OPTION, JOptionPane.PLAIN_MESSAGE);",
		"					System.exit(1);",
		"				}",
		"				return r2.getReplVal();",
		"			} else if(r2.isHalt()) {",
		"				JOptionPane.showConfirmDialog(null, \"Forced halt from LoPSiL\" + \"\\nSystem will now exit.\", \"Error!\",",
		"					JOptionPane.DEFAULT_OPTION, JOptionPane.PLAIN_MESSAGE);",
		"				System.exit(1);",
		"			} else {",
		"				try{ throw r2.getException();",
		"				} catch (Exception e) {}",
		"			}",
		"		} else if(r1.isReplace()) {",
		"			try {",
		"				r1.checkReplVal(thisJoinPoint.getSignature().getDeclaringType());",
		"				} catch (LopsilException le) {",
		"					JOptionPane.showConfirmDialog(null, le.toString() +  \"\\nSystem will now exit.\", \"Error!\", +",
		"						JOptionPane.DEFAULT_OPTION, JOptionPane.PLAIN_MESSAGE);",
		"				System.exit(1);",
		"		 	}",
		"			 	return r1.getReplVal();",
		"		} else if(r1.isHalt()) {",
		"				JOptionPane.showConfirmDialog(null, \"Forced halt from LoPSiL\" + \"\\nSystem will now exit.\", \"Error!\", ",
		"					JOptionPane.DEFAULT_OPTION, JOptionPane.PLAIN_MESSAGE);",
		"				System.exit(1);",
		"		} else {",
		"				try{ throw r1.getException();",
		"				} catch (Exception e) {}",
		"		}",
		"		return result;\n\t}\n}"};

	public static void main(String args[])
	{
		String policy = (String)JOptionPane.showInputDialog(null, 
			"Enter .lopsil file name (without the extension):", 
			"LoPSiL Converter", JOptionPane.QUESTION_MESSAGE);
		if (policy == null)
			System.exit(-1);
		String srm = (String)JOptionPane.showInputDialog(null, 
			"Enter .srm file name (without the extension):", 
			"LoPSiL Converter", JOptionPane.QUESTION_MESSAGE);
		if (srm == null)
			System.exit(-1);
		String pkg = (String)JOptionPane.showInputDialog(null, 
			"Enter name of package:", "LoPSiL Converter", 
			JOptionPane.QUESTION_MESSAGE);
		if (pkg == null)
			System.exit(-1);
		String mainCls = (String)JOptionPane.showInputDialog(null, 
			"Enter name of main class of package:", "LoPSiL Converter", 
			JOptionPane.QUESTION_MESSAGE);
		if (mainCls == null)
			System.exit(-1);
		policy = policy + ".lopsil";
		srm = srm + ".srm";
		convert(policy, srm, pkg, mainCls);
	}
	public static void convert(String lopsil, String srm, String pkg, String mainClass)
	{
		String lopsilClass = lopsil.substring(0, lopsil.length() - 7);
		String srmClass = srm.substring(0, srm.length() - 4);
		String lopsilFile = lopsil.substring(0, lopsil.length() - 6) + "java";
		String srmFile = srm.substring(0, srm.length() - 3) + "aj";
		BufferedReader inputStream;
		BufferedWriter outputStream;
		//Check whether specified .lopsil file exists
		try
		{
			inputStream=new BufferedReader(new FileReader(lopsil));
		}
		catch(IOException e)
		{
			JOptionPane.showMessageDialog(null, "<HTML><I>" + lopsil + 
				"</I> does not exist.", "Error", JOptionPane.ERROR_MESSAGE);
			System.exit(-1);
		}
		//Check whether specified .srm file exists
		try
		{
			inputStream = new BufferedReader(new FileReader(srm));
		}
		catch (IOException e)
		{
			JOptionPane.showMessageDialog(null, "<HTML><I>" + srm + 
				"</I> does not exist.", "Error", JOptionPane.ERROR_MESSAGE);
			System.exit(-1);
		}	

		//Convert .lopsil to .java
		try
		{
			inputStream = new BufferedReader(new FileReader(lopsil));
			outputStream = new BufferedWriter(new FileWriter(lopsilFile));
			String bufferedText;
			for (int i = 0; i < javaCode.length; i++)
				outputStream.write(javaCode[i] + "\n");
			while ((bufferedText = inputStream.readLine()) != null)
			{
				outputStream.write(bufferedText + "\n");
			}
			outputStream.close();
		}
		catch (IOException e)
		{
			JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
			System.exit(-1);
		}	//End convert .lopsil to .java

		//Convert .srm to .aj
		try
		{   //Write out the top part of .aj file
			String bufferedText;
			outputStream = new BufferedWriter(new FileWriter(srmFile));
			outputStream.write("import lopsil.*;\nimport javax.swing.JOptionPane;\n\n");
			outputStream.write("public aspect " + srmClass + " {\n\n");
			outputStream.write("\tprivate " + lopsilClass + " p;\n\n");
			outputStream.write("\tpointcut notInAdvice():\n");
			outputStream.write("\t\t!cflow(adviceexecution()) && !within(" + srmClass + ") && !within(lopsil..*) && !within(gpslib4j..*);\n\n");
			outputStream.write("\tpointcut srmCalls()");
			//Write out all the security relevant functions in AspectJ format
			inputStream = new BufferedReader(new FileReader(srm));
			ArrayList securityRelMethods = new ArrayList();
			while ((bufferedText = inputStream.readLine()) != null)
			{
				if (bufferedText.startsWith("!")||bufferedText.trim().equals(""))
					continue;
				else
					securityRelMethods.add(bufferedText);
			}
			int noOfSrms = securityRelMethods.size();
			if (noOfSrms == 0)
				outputStream.write(";\n");
			else
				outputStream.write(":\n");
			for (int i = 0; i < noOfSrms; i++)
			{
				String methodName = (String)securityRelMethods.get(i);
				if (i == noOfSrms - 1)
					methodName = "\t\tcall(" + methodName + ");\n";
				else
					methodName = "\t\tcall(" + methodName + ") ||\n";
				outputStream.write(methodName);
			}
			//Write out the bottom part of .aj file
			outputStream.write("\n\n\tafter(): staticinitialization(" + pkg + "." + mainClass + ") {\n");
			outputStream.write("\tp = new " + lopsilClass + "();\n}\n\n");
			for (int i = 0; i < AJcode.length; i++)
			{
				outputStream.write(AJcode[i] + "\n");
			}
			outputStream.close();
		}
		catch (IOException e)
		{
			JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
			System.exit(-1);
		}	//End convert .srm to .aj
		JOptionPane.showMessageDialog(null, "Task completed successfully.", "Complete", JOptionPane.INFORMATION_MESSAGE);
	}
} // end LopsilConverter