package lopsil.device;
import lopsil.*;

import java.util.Calendar;
import java.util.Date;

/* This class defines time-based  utilities used in LoPSiL
 * 
 * @author Billy Rickey
 * @author Jay Ligatti
 * @author Nalin Saigal
 * 
*/

public class Time
{
	private long timeValue;
	public static final lopsil.device.Time NEVER = new lopsil.device.Time(-1);

	/* Constructor */
	public Time(long value) { timeValue = value; }

	/* Returns the value of time */
	public long getTime() { return timeValue; }

	/* Sets the value of time */
	public void setTime(long time) { timeValue = time; }

	/* Displays the current time in HH:MM:SS format */
	public void displayTime()
	{
		java.sql.Time newTime = new java.sql.Time(this.timeValue);
		System.out.println(newTime.toString());
	}
	
	/* Returns the time elapsed from the specified time in the requisite units 
	 * time > Time of caller object */
	public long elapsed(lopsil.device.Time time, int units)
	{
		long elapsedTimeMS = time.timeValue - this.timeValue;
		long multiplier = (new Double(Units.getMultiplier(units))).longValue();
		return elapsedTimeMS / multiplier;

	}

	/* Returns the current time */
	public static lopsil.device.Time getCurrentTime() { return (new lopsil.device.Time(System.currentTimeMillis())); }

	/* isWorkTime() returns true if current time is working 
	 * time, defined by Monday through Friday 8AM - 6PM. */
	public static boolean isWorkTime()
	{
		Calendar cal = Calendar.getInstance();
		int dow = cal.get(Calendar.DAY_OF_WEEK);
		int hod = cal.get(Calendar.HOUR_OF_DAY);
		if (dow == 7 || dow == 1)
			return false;
		else if (hod >= 8 && hod < 18)
			return true;
		else
			return false;
	}
}