package lopsil.device;

import java.io.*;
import javax.comm.*;
import gpslib4j.*;
import gpslib4j.Garmin.*;

/**
 * This file defines all the units of length and time used
 * within LoPSiL
 * 
 * @author Billy Rickey
 * @author Jay Ligatti
 * @author Nalin Saigal
 * 
 */
public class Units
{
	public static final int YARDS = 1;//1.0;
	/** LocationGranularityAssumption measurement for feet. */
	public static final int FEET = 2;//1.0 / 3.0;
	/** LocationGranularityAssumption measurement for inches. */
	public static final int INCHES = 3;//1.0 / 36.0;
	/** LocationGranularityAssumption measurement for miles. */
	public static final int MILES = 4;//1760.0;
	/** LocationGranularityAssumption measurement for meters. */
	public static final int METERS = 5;//100.0 / 2.54 / 36.0;
	/** LocationGranularityAssumption measurement for centimeters. */
	public static final int CENTIMETERS = 6;// 1.0 / 2.54 / 36.0;
	/** LocationGranularityAssumption measurement for centimeters. */
	public static final int KILOMETERS = 7;//100000.0 / 2.54 / 36.0;
	/** LocationGranularityAssumption measurement for infinity. */
	public static final int INFINITY = 8;//1.0 / 0.0;

	public static final int MILSECONDS = 9;
	public static final int SECONDS = 10;
	public static final int MINUTES = 11;
	public static final int HOURS = 12;

	public static double getMultiplier(int scale)
	{
		double multiplier = 1.0;
		switch (scale)
		{
			case Units.INCHES:
				multiplier = 1.0 / (12.0 * 5280.0);
				break;
			case Units.FEET:
				multiplier = 1.0 / 5280.0;
				break;
			case Units.YARDS:
				multiplier = 3.0 / 5280.0;
				break;
			case Units.MILES:
				multiplier = 1.0;
				break;
			case Units.CENTIMETERS:
				multiplier = 1.0 / (2.54 * 12.0 * 5280.0);
				break;
			case Units.METERS:
				multiplier = 100.0 / (2.54 * 12.0 * 5280.0);
				break;
			case Units.KILOMETERS:
				multiplier = (1000.0 * 100.0) / (2.54 * 12.0 * 5280.0);
				break;
			case Units.MILSECONDS:
				multiplier = 1.0;
				break;
			case Units.SECONDS:
				multiplier = 1000.0;
				break;
			case Units.MINUTES:
				multiplier = 60.0 * 1000.0;
				break;
			case Units.HOURS:
				multiplier = 60.0 * 60.0 * 1000.0;
				break;
		}
		return multiplier;
	}
} // end Units